package de.intevation.flys.artifacts.model;

import org.apache.log4j.Logger;

import java.util.List;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;
import de.intevation.artifacts.DataProvider;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.flys.artifacts.WaterLineArtifact;

import de.intevation.flys.model.FastCrossSectionLine;

import de.intevation.flys.geom.Lines;

/**
 * Facet for Waterlines in Cross Sections.
 */
public class CrossSectionWaterLineFacet
extends      BlackboardDataFacet
implements   FacetTypes {

    private static Logger logger = Logger.getLogger(CrossSectionWaterLineFacet.class);


    /** Trivial constructor, set (maybe localized) description. */
    public CrossSectionWaterLineFacet(int idx, String description) {
        super(idx, CROSS_SECTION_WATER_LINE, description);
    }


    /**
     * Gets waterline (crossed with cross section) of waterlevel.
     */
    public Object getData(Artifact artifact, CallContext context) {
        logger.debug("Get data for cross section water line");

        List<DataProvider> providers = context.
            getDataProvider(CrossSectionFacet.BLACKBOARD_CS_MASTER_DATA);
        if (providers.size() < 1) {
            logger.warn("Could not find Cross-Section data provider.");
            return new Lines.LineData(new double[][] {}, 0d, 0d);
        }
        
        Object crossSection = providers.get(0)
            .provideData(CrossSectionFacet.BLACKBOARD_CS_MASTER_DATA, null, context);

        WaterLineArtifact winfo = (WaterLineArtifact)artifact;

        if (crossSection != null) {
            return winfo.getWaterLines(this.getIndex(),
                (FastCrossSectionLine) crossSection);
        }
        else {
            return new Lines.LineData(new double[][] {}, 0d,0d);
        }
    }


    /** Do a deep copy. */
    @Override 
    public Facet deepCopy() {
        CrossSectionWaterLineFacet copy = new CrossSectionWaterLineFacet(
            this.getIndex(),
            this.description);
        copy.set(this);
        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
